@@ -52,6 +52,9 @@ class __PharmacophoreBase():
     def __drop_cache(self):
         self.__cache = dict()
 
+    def _get_cached(self):
+        return self.__cached
+
     @staticmethod
     def __remove_dupl(ls):
         # remove duplicates preserving the order of items
@@ -330,18 +333,6 @@ class __PharmacophoreBase():
             output[data['label']].append(i)
         return {k: tuple(v) for k, v in output.items()}
 
-    def get_mirror_pharmacophore(self):
-        """
-        Returns a new mirrored Pharmacophore instance.
-
-        :return: a new instance of a Pharmacophore class with all features mirrored in yz-plane.
-
-        """
-        p = Pharmacophore()
-        coords = tuple((label, (-x, y, z)) for label, (x, y, z) in self.get_feature_coords())
-        p.load_from_feature_coords(coords)
-        return p
-
     def update(self, bin_step=None, cached=None):
         """
         Changes parameters of the pharmacophore instance.
@@ -570,14 +561,14 @@ class __PharmacophoreMatch(__PharmacophoreMol):
         :param tol: tolerance
         :type tol: float
         :param get_transform_matrix: if set, the function will return a transformation matrix as an additional output
-                                     to align the pharmacopore to a model
+                                     to align the pharmacophore to a model
         :type get_transform_matrix: bool
         :param get_rms: if set True, the function will return rms value of matched pharmacophore
         :return: None if a model does not match; if matched the output depends on set arguments.
-                 By default output is a tuple of feature ids of a model matching the pharmacophore.
-                 If get_transform_matrix or get_rms arguments were set to True the output will be 2 or 3-tuple, where
-                 the first item if a tuple of matched features ids, the next items are a transformation matrix and/or
-                 rms value.
+                 By default output is a dictionary of current pharmacophore feature ids (keys) and mapped model feature
+                 ids (values). If get_transform_matrix or get_rms arguments were set to True the output will be
+                 2 or 3-tuple, where the first item if a tuple of matched features ids, the next items are
+                 a transformation matrix and/or rms value.
 
         """
 
@@ -603,7 +594,7 @@ class __PharmacophoreMatch(__PharmacophoreMol):
                         if j == 0:
                             ref = model.get_signature_md5(ids=tuple(mapping.values()), tol=tol)
                         if self.get_signature_md5(ids=tuple(mapping.keys()), tol=tol) == ref:
-                            output = tuple(mapping.values())
+                            output = mapping
                             if get_transform_matrix or get_rms:
                                 output = (output,)
                                 rms, matrix = self.__get_transformation_matrix_and_rms(model, mapping)
@@ -620,7 +611,7 @@ class __PharmacophoreMatch(__PharmacophoreMol):
                 if j == 0:
                     ref = model.get_signature_md5(tol=tol)
                 if self.get_signature_md5(ids=tuple(mapping.keys()), tol=tol) == ref:
-                    output = tuple(mapping.values())
+                    output = mapping
                     if get_transform_matrix or get_rms:
                         output = (output, )
                         rms, matrix = self.__get_transformation_matrix_and_rms(model, mapping)
@@ -819,10 +810,10 @@ class __PharmacophoreLoadedMol(__PharmacophoreMatch):
         return output
 
 
-class Pharmacophore(__PharmacophoreLoadedMol):
+class __PharmacophoreFiles(__PharmacophoreLoadedMol):
 
     """
-    Main class
+    The class to support reading and writing pharmacophores in different formats
 
     """
 
@@ -1040,3 +1031,37 @@ class Pharmacophore(__PharmacophoreLoadedMol):
                                    'enabled': True})
         with open(fname, 'wt') as f:
             json.dump(data, f, indent=4)
+
+
+class Pharmacophore(__PharmacophoreFiles):
+
+    """
+    Main class
+
+    """
+
+    def get_mirror_pharmacophore(self):
+        """
+        Returns a new mirrored Pharmacophore instance. Bin step and cached arguments will be the same as for
+        the source instance.
+
+        :return: a new instance of a Pharmacophore class with all features mirrored in yz-plane.
+
+        """
+        p = Pharmacophore(bin_step=self.get_bin_step(), cached=self._get_cached())
+        coords = tuple((label, (-x, y, z)) for label, (x, y, z) in self.get_feature_coords())
+        p.load_from_feature_coords(coords)
+        return p
+
+    def get_subpharmacophore(self, ids=None):
+        """
+        Returns a new Pharmacophore instance with chosen features. Bin step and cached arguments will be the same as
+        for the source instance.
+
+        :param ids: a list of chosen feature ids or None (all features)
+        :return: a new instance containing only selected feature.
+
+        """
+        p = Pharmacophore(bin_step=self.get_bin_step(), cached=self._get_cached())
+        p.load_from_feature_coords(self.get_feature_coords(ids=ids))
+        return p
